@@ -1,5 +1,5 @@
 
-#Copyright (c) 2009-2022 Sebastien Bihorel
+#Copyright (c) 2009-2026 Sebastien Bihorel
 #All rights reserved.
 #
 #This file is part of scaRabee.
@@ -272,7 +272,7 @@ scarabee.analysis <- function(files=NULL,
       sink()
   })
   
-  if (class(anatry)=="try-error") setwd(oldwd)
+  if (methods::is(anatry,"try-error")) setwd(oldwd)
   
 }
 
