@@ -1,5 +1,5 @@
 
-#Copyright (c) 2009-2022 Sebastien Bihorel
+#Copyright (c) 2009-2026 Sebastien Bihorel
 #All rights reserved.
 #
 #This file is part of scaRabee.
@@ -78,7 +78,7 @@ scarabee.gridsearch <- function(problem=NULL,
             },
             silent=TRUE)
           
-          if (class(tmp)=="try-error"){
+          if (methods::is(tmp,'try-error')){
             cat(paste('An error occured during the computation of the model',
                 'predictions or the negative log likelihood.\n'))
             ML <- Inf
