@@ -1,5 +1,5 @@
 
-#Copyright (c) 2009-2022 Sebastien Bihorel
+#Copyright (c) 2009-2026 Sebastien Bihorel
 #All rights reserved.
 #
 #This file is part of scaRabee.
@@ -46,22 +46,22 @@ scarabee.read.parms <- function(files=NULL){
                        'is empty. Please, check the content of your file.'),
                  files$param))
   
-  if (class(param$names)!='character')
+  if (!methods::is(param$names,'character'))
     param$names <- as.character(param$names)
   
-  if (class(param$type)!='character')
+  if (!methods::is(param$type,'character'))
     param$type <- as.character(param$type)
   
-  if (class(param$value)!='numeric')
+  if (!methods::is(param$value,'numeric'))
     param$value <- as.numeric(param$value)
   
-  if (class(param$isfix)!='integer')
+  if (!methods::is(param$isfix,'integer'))
     param$isfix <- as.numeric(param$isfix)
   
-  if (class(param$lb)!='numeric')
+  if (!methods::is(param$lb,'numeric'))
     param$lb <- as.numeric(param$lb)
   
-  if (class(param$ub)!='numeric')
+  if (!methods::is(param$ub,'numeric'))
     param$ub <- as.numeric(param$ub)
   
   if (any(is.na(param$names)))
